@@ -1,3 +1,4 @@
+
 oldwd <- getwd()
 setwd(tempdir())
 
@@ -11,19 +12,18 @@ G = tcrossprod(M)                    # Genomic relationship matrix
 y = as.vector(scale(Y[,'E1']))       # Subset response variable
 
 # Predicting a testing set using training set
-tst = which(Y$trial %in% 2)
-trn = (seq_along(y))[-tst]
+trn_tst = ifelse(Y$trial %in% 2, 0, 1)
 
 # Obtain lambda from cross-validation (in traning set)
-fm1 = SSI.CV(y,K=G,trn=trn,nfolds=5,nCV=3)
+fm1 = SSI.CV(y,K=G,trn_tst=trn_tst,nfolds=5,nCV=3)
 lambda = summary(fm1)$optCOR["lambda"]
 
 # Fit the index with the obtained lambda
-fm2 = SSI(y,K=G,theta=NULL,trn=trn,tst=tst,lambda=lambda)
+fm2 = SSI(y,K=G,trn_tst=trn_tst,lambda=lambda)
 summary(fm2)$accuracy        # Testing set accuracy
 
 # Compare the accuracy with that of the non-sparse index
-fm3 = SSI(y,K=G,theta=NULL,trn=trn,tst=tst,lambda=0)
+fm3 = SSI(y,K=G,trn_tst=trn_tst,lambda=0)
 summary(fm3)$accuracy
 
 setwd(oldwd)
