@@ -13,42 +13,45 @@ y = as.vector(scale(Y[,'E1']))       # Subset response variable
 
 # Calculate variance components ratio using all data
 fm1 = fitBLUP(y,K=G)
-theta = fm1$varE/fm1$varU
-h2 = fm1$varU/(fm1$varU + fm1$varE)
+varU = fm1$varU
+varE = fm1$varE
+h2 = varU/(varU + varE)
 
 # Sparse selection index
-fm2 = SSI(y,K=G,theta=theta,nlambda=50)
+fm2 = SSI(y,K=G,varU=varU,varE=varE,nlambda=50)
 
-# The same but passing the heritability instead of theta
-fm2 = SSI(y,K=G,h2=h2,nlambda=50)
+# The same but without passing variance components
+fm2 = SSI(y,K=G,nlambda=50)
 u2 = fitted(fm2)
 
 plot(fm2)  # Penalization vs accuracy
 
 # Equivalence of the SSI with lambda=0 with G-BLUP
-fm3 = SSI(y,K=G,theta=theta,lambda=0,tol=1E-5)
+fm3 = SSI(y,K=G,varU=varU,varE=varE,lambda=0,tol=1E-5)
 
 cor(y, fm1$u)        # G-BLUP accuracy
 cor(y, fitted(fm3))  # SSI accuracy
 cor(fm1$u, fitted(fm3))
 
 # Predicting a testing set using training set
-tst = which(Y$trial %in% 2)
-trn = (seq_along(y))[-tst]
+# 0: testing, 1:training
+trn_tst = ifelse(Y$trial %in% 2, 0, 1)
 
 # Calculate variance components in training data
 yNA = y
-yNA[tst] = NA
+yNA[trn_tst==0] = NA
 fm1 = fitBLUP(yNA,K=G)
-(theta = fm1$varE/fm1$varU)
-(h2 = fm1$varU/(fm1$varU + fm1$varE))
+(varU = fm1$varU)
+(varE = fm1$varE)
+(h2 = varU/(varU + varE))
 
 # Sparse selection index
-fm2 = SSI(y,K=G,theta=theta,trn=trn,tst=tst)
+fm2 = SSI(y,K=G,varU=varU,varE=varE,trn_tst=trn_tst)
 
-# Variance components ratio internaly calculated
-fm2 = SSI(y,K=G,theta=NULL,trn=trn,tst=tst)
-fm2$theta
+# Variance components internaly calculated
+fm2 = SSI(y,K=G,trn_tst=trn_tst)
+fm2$varU
+fm2$varE
 fm2$h2
 
 # Effect of the penalization on the accuracy
